@@ -9,7 +9,6 @@ import { useQueryLibraryContext } from 'app/features/explore/QueryLibrary/QueryL
 import { SavedQuery } from 'app/features/explore/QueryLibrary/types';
 import icnDatasourceSvg from 'img/icn-datasource.svg';
 
-import { QueryLibraryInteractions } from '../QueryLibraryAnalyticsEvents';
 import { selectors } from '../e2e-selectors/selectors';
 import { useDatasource } from '../utils/useDatasource';
 
@@ -25,7 +24,6 @@ export interface QueryListItemProps {
   usingHistory?: boolean;
   isNew?: boolean;
   disabled?: boolean;
-  setIsEditingQuery?: (isEditingQuery: boolean) => void;
 }
 
 const RADIO_GROUP_NAME = 'query-library-list';
@@ -42,22 +40,11 @@ function QueryLibraryItemComponent({
   usingHistory,
   isNew,
   disabled,
-  setIsEditingQuery,
 }: QueryListItemProps) {
   const { value: datasourceApi } = useDatasource(queryRow.datasourceRef);
   const styles = useStyles2(getStyles);
 
-  const { setNewQuery, triggerAnalyticsEvent } = useQueryLibraryContext();
-
-  const onAddHistoryQueryToLibrary = () => {
-    setNewQuery({
-      ...queryRow,
-      uid: undefined,
-      title: t('explore.query-library.default-title', 'New query'),
-    });
-    setIsEditingQuery?.(true);
-    triggerAnalyticsEvent(QueryLibraryInteractions.saveRecentQueryClicked);
-  };
+  const { onAddHistoryQueryToLibrary } = useQueryLibraryContext();
 
   return (
     <label
@@ -105,6 +92,7 @@ function QueryLibraryItemComponent({
             onClick={isFavorite ? onUnfavorite : onFavorite}
             iconType={isFavorite ? 'mono' : 'default'}
             disabled={disabled}
+            data-testid={selectors.components.queryLibraryDrawer.favoriteButton}
           />
         )}
 
@@ -113,7 +101,13 @@ function QueryLibraryItemComponent({
             id={`history-${queryRow.uid}`}
             tooltip={t('query-library.item.add-to-library', 'Save query')}
             name="plus-circle"
-            onClick={onAddHistoryQueryToLibrary}
+            onClick={() =>
+              onAddHistoryQueryToLibrary({
+                ...queryRow,
+                uid: undefined,
+                title: t('explore.query-library.default-title', 'New query'),
+              })
+            }
             iconType="default"
           />
         )}
@@ -170,7 +164,7 @@ const getStyles = (theme: GrafanaTheme2) => ({
     position: 'relative',
 
     // Add transitions for smooth highlighting fade-out
-    '@media (prefers-reduced-motion: no-preference)': {
+    [theme.transitions.handleMotion('no-preference')]: {
       transition: theme.transitions.create(['background-color', 'border-color'], {
         duration: theme.transitions.duration.standard,
       }),
@@ -212,7 +206,9 @@ const getStyles = (theme: GrafanaTheme2) => ({
     },
   }),
   logo: css({
-    width: '16px',
+    width: '20px',
+    height: 'auto',
+    objectFit: 'contain',
   }),
   disabled: css({
     opacity: 0.5,
